Module blaxel.core.client.models.preview_spec_response_headers
==============================================================

Classes
-------

`PreviewSpecResponseHeaders()`
:   Those headers will be set in all responses of your preview. This is especially useful to set the CORS headers.
    
    Method generated by attrs for class PreviewSpecResponseHeaders.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, str]`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :